.First.lib <- function(libname, pkgname)
  {
    if(is.R())
      {
        library(stats)
        library(MASS)   
      }
  }
